@@ -137,3 +137,29 @@ SECURE_BOOT_RESET_KEYS = {
 }
 
 SECURE_BOOT_RESET_KEYS_REV = utils.revert_dictionary(SECURE_BOOT_RESET_KEYS)
+
+SECURE_BOOT_DATABASE_TYPE = {
+    'PK': sys_cons.SECURE_BOOT_PLATFORM_KEY,
+    'KEK': sys_cons.SECURE_BOOT_KEY_EXCHANGE_KEYS,
+    'db': sys_cons.SECURE_BOOT_ALLOWED_KEYS_DATABASE,
+    'dbx': sys_cons.SECURE_BOOT_DENIED_KEYS_DATABASE,
+    'dbr': sys_cons.SECURE_BOOT_RECOVERY_KEYS_DATABASE,
+    'dbt': sys_cons.SECURE_BOOT_TIMESTAMP_DATABASE,
+    'PKDefault': sys_cons.SECURE_BOOT_DEFAULT_PLATFORM_KEY,
+    'KEKDefault': sys_cons.SECURE_BOOT_DEFAULT_KEY_EXCHANGE_KEYS,
+    'dbDefault': sys_cons.SECURE_BOOT_DEFAULT_ALLOWED_KEYS_DATABASE,
+    'dbxDefault': sys_cons.SECURE_BOOT_DEFAULT_DENIED_KEYS_DATABASE,
+    'dbrDefault': sys_cons.SECURE_BOOT_DEFAULT_RECOVERY_KEYS_DATABASE,
+    'dbtDefault': sys_cons.SECURE_BOOT_DEFAULT_TIMESTAMP_DATABASE,
+}
+
+SECURE_BOOT_DATABASE_TYPE_REV = utils.revert_dictionary(
+    SECURE_BOOT_DATABASE_TYPE)
+
+SECURE_BOOT_DATABASE_RESET_KEYS = {
+    'ResetAllKeysToDefault': sys_cons.SECURE_BOOT_RESET_KEYS_TO_DEFAULT,
+    'DeleteAllKeys': sys_cons.SECURE_BOOT_RESET_KEYS_DELETE_ALL,
+}
+
+SECURE_BOOT_DATABASE_RESET_KEYS_REV = utils.revert_dictionary(
+    SECURE_BOOT_DATABASE_RESET_KEYS)
